// Expert Advisor parameters
extern double TakeProfit = 600;   // Take profit in pips
extern double StopLoss = 300;    // Stop loss in pips
extern double LotSize = 0.01;   // Trade volume
extern int LookbackPeriod = 26;  // Number of candles to look back

// Function to place a buy order
void PlaceBuyOrder(double price)
{
    double stopLossPrice = price - StopLoss * Point;
    double takeProfitPrice = price + TakeProfit * Point;
    int ticket = OrderSend(_Symbol, OP_BUY, LotSize, price, 0, stopLossPrice, takeProfitPrice);
    if (ticket > 0)
    {
        Print("Buy order placed at price: ", price);
    }
    else
    {
        Print("Failed to place buy order. Error code: ", GetLastError());
    }
}

// Function to place a sell order
void PlaceSellOrder(double price)
{
    double stopLossPrice = price + StopLoss * Point;
    double takeProfitPrice = price - TakeProfit * Point;
    int ticket = OrderSend(_Symbol, OP_SELL, LotSize, price, 0, stopLossPrice, takeProfitPrice);
    if (ticket > 0)
    {
        Print("Sell order placed at price: ", price);
    }
    else
    {
        Print("Failed to place sell order. Error code: ", GetLastError());
    }
}

// Function to find the highest high in the last n candles
double FindHighestHigh(int lookbackPeriod)
{
    double highestHigh = 0;
    for (int i = 1; i <= lookbackPeriod; i++)
    {
        double highPrice = High[i];
        if (highPrice > highestHigh)
        {
            highestHigh = highPrice;
        }
    }
    return highestHigh;
}

// Function to find the lowest low in the last n candles
double FindLowestLow(int lookbackPeriod)
{
    double lowestLow = EMPTY_VALUE;
    for (int i = 1; i <= lookbackPeriod; i++)
    {
        double lowPrice = Low[i];
        if (lowPrice < lowestLow || lowestLow == EMPTY_VALUE)
        {
            lowestLow = lowPrice;
        }
    }
    return lowestLow;
}

// Expert Advisor start function
int start()
{
    double highestHigh = FindHighestHigh(LookbackPeriod);
    double lowestLow = FindLowestLow(LookbackPeriod);

    // Set buy order with (highest high - 2100 points)
    double buyOrderPrice = highestHigh - 2100 * Point;
    PlaceBuyOrder(buyOrderPrice);

    // Set sell order with (lowest low + 2100 points)
    double sellOrderPrice = lowestLow + 2100 * Point;
    PlaceSellOrder(sellOrderPrice);

    return 0;
}
